BUF_BIN ?= cmd/buf

PROTOREFLECT_VERSION := 11eaaf73e0ec2d04934c5d86d46577568463cc86
# Remove when https://github.com/spf13/cobra/pull/1070 is released
COBRA_VERSION := 884edc58ad08083e6c9a505041695aa2c3ca2d7a
# Remove when https://github.com/ory/dockertest/issues/208 is fixed
GOLANG_X_SYS_VERSION := f9321e4c35a6ee62ff0348f57ad5a3b5e73e299e
GO_GET_PKGS := $(GO_GET_PKGS) \
	github.com/jhump/protoreflect@$(PROTOREFLECT_VERSION) \
	github.com/spf13/cobra@$(COBRA_VERSION) \
	golang.org/x/sys@$(GOLANG_X_SYS_VERSION)
GO_BINS := $(GO_BINS) \
	$(BUF_BIN) \
	cmd/protoc-gen-buf-check-breaking \
	cmd/protoc-gen-buf-check-lint \
	internal/pkg/storage/cmd/storage-go-binary-data \
	internal/pkg/app/appproto/appprotoexec/cmd/protoc-gen-proxy
GO_TEST_BINS := $(GO_TEST_BINS) \
	internal/buf/cmd/buf/command/protoc/internal/protoc-gen-insertion-point-receiver \
	internal/buf/cmd/buf/command/protoc/internal/protoc-gen-insertion-point-writer
DOCKER_BINS := $(DOCKER_BINS) buf
PROTOC_GEN_GO_OUT := internal/gen/proto/go
PROTOC_GEN_VALIDATE_OUT := internal/gen/proto/go
FILE_IGNORES := $(FILE_IGNORES) \
	.build/ \
	.vscode/ \
	internal/buf/cmd/buf/cache/ \
	internal/buf/internal/buftesting/cache/ \
	internal/pkg/storage/storageos/tmp/

USE_BUF_GENERATE := true

include make/go/bootstrap.mk
include make/go/go.mk
include make/go/codecov.mk
include make/go/dep_protoc.mk
include make/go/docker.mk
include make/go/protoc_gen_go.mk
include make/go/dep_go_fuzz.mk

# Settable
BUF_BREAKING_INPUT ?= .git\#branch=master

installtest:: $(PROTOC) $(PROTOC_GEN_GO)

.PHONY: wkt
wkt: installstorage-go-binary-data $(PROTOC)
	rm -rf internal/gen/data
	mkdir -p internal/gen/data/wkt
	storage-go-binary-data $(CACHE_INCLUDE) --package wkt > internal/gen/data/wkt/wkt.gen.go

prepostgenerate:: wkt

.PHONY: buflint
buflint: installbuf
	buf check lint

.PHONY: bufbreaking
bufbreaking: installbuf
ifneq ($(BUF_BREAKING_INPUT),)
	-buf check breaking --against-input $(BUF_BREAKING_INPUT)
else
	@echo "skipping make bufbreaking" >&2
endif

postlint:: buflint bufbreaking

.PHONY: bufrelease
bufrelease:
	DOCKER_IMAGE=golang:1.15.2-buster bash make/buf/scripts/release.bash

.PHONY: gofuzz
gofuzz: $(GO_FUZZ)
	@rm -rf $(TMP)/gofuzz
	@mkdir -p $(TMP)/gofuzz
	cd internal/buf/bufbuild/bufbuildtesting; go-fuzz-build -o $(abspath $(TMP))/gofuzz/gofuzz.zip
	go-fuzz -bin $(TMP)/gofuzz/gofuzz.zip -workdir $(TMP)/gofuzz
